"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dynamodb_1 = require("aws-sdk/clients/dynamodb");
const Umzug = require("umzug");
const dynamodb_2 = require("./storages/dynamodb");
/**
 * Migrator factory function, creates an umzug instance with dynamodb storage.
 * @param options
 * @param options.dynamodb - a DynamoDB document client instance
 * @param options.migrationTable - name of migration table in DynamoDB
 */
function migratorFactory({ dynamodb, migrationTable } = {}) {
    dynamodb = dynamodb || new dynamodb_1.DocumentClient();
    const tableName = migrationTable || 'migrations';
    return new Umzug({
        storage: new dynamodb_2.default({ dynamodb, tableName }),
        migrations: {
            params: [dynamodb],
        },
        logging: function (...args) {
            console.log.apply(null, args);
        }
    });
}
exports.migratorFactory = migratorFactory;
/**
 * Migrator instance with options by default.
 */
exports.defaultMigrator = migratorFactory();
